==> carbon-components-react-0.2.8.tgz: package/lib/components/ButtonGroup/ButtonGroup-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonKnobs = require("@storybook/addon-knobs");

var _ButtonGroup = _interopRequireDefault(require("../ButtonGroup"));

var _OverflowMenuItem = _interopRequireDefault(require("../OverflowMenuItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var kinds = {
  'Primary button (primary)': 'primary',
  'Secondary button (secondary)': 'secondary',
  'Danger button (danger)': 'danger',
  'Ghost button (ghost)': 'ghost'
};
var sizes = {
  Default: 'default',
  Field: 'field',
  Small: 'small'
};
var props = {
  regular: function regular() {
    return {
      buttonLabel: (0, _addonKnobs.text)('Button Label', 'Button Label'),
      size: (0, _addonKnobs.select)('Button size (size)', sizes, 'default'),
      kind: (0, _addonKnobs.select)('Button kind (kind)', kinds, 'primary'),
      disabled: (0, _addonKnobs.boolean)('Disabled (disabled)', false)
    };
  }
};
(0, _react2.storiesOf)('ButtonGroup', module).addDecorator(_addonKnobs.withKnobs).add('Default', function () {
  var regularProps = props.regular();
  return _react.default.createElement(_ButtonGroup.default, regularProps, _react.default.createElement(_OverflowMenuItem.default, {
    itemText: 'Item 1'
  }), _react.default.createElement(_OverflowMenuItem.default, {
    itemText: 'Item 2'
  }), _react.default.createElement(_OverflowMenuItem.default, {
    itemText: 'Item 3'
  }));
}, {
  info: {
    text: "\n        ButtonGroup Component\n        "
  }
});

==> carbon-components-react-0.8.1.tgz: package/lib/components/ButtonGroup/ButtonGroup-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonKnobs = require("@storybook/addon-knobs");

var _ButtonGroup = _interopRequireDefault(require("../ButtonGroup"));

var _OverflowMenuItem = _interopRequireDefault(require("../OverflowMenuItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var kinds = {
  'Primary button (primary)': 'primary',
  'Secondary button (secondary)': 'secondary',
  'Danger button (danger)': 'danger',
  'Ghost button (ghost)': 'ghost'
};
var sizes = {
  Default: 'default',
  Field: 'field',
  Small: 'small'
};
var props = {
  regular: function regular() {
    return {
      buttonLabel: (0, _addonKnobs.text)('Button Label', 'Button Label'),
      size: (0, _addonKnobs.select)('Button size (size)', sizes, 'default'),
      kind: (0, _addonKnobs.select)('Button kind (kind)', kinds, 'primary'),
      disabled: (0, _addonKnobs.boolean)('Disabled (disabled)', false)
    };
  }
};
(0, _react2.storiesOf)('Pattern|ButtonGroup', module).addDecorator(_addonKnobs.withKnobs).add('Default', function () {
  var regularProps = props.regular();
  return /*#__PURE__*/_react.default.createElement(_ButtonGroup.default, regularProps, /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
    primaryFocus: true,
    itemText: 'Item 1'
  }), /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
    itemText: 'Item 2'
  }), /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
    itemText: 'Item 3'
  }));
}, {
  info: {
    text: "\n        ButtonGroup Component\n        "
  }
});
